@@ -9,12 +9,12 @@ class RawResponseItem(Item):
     appid = Field()
     crawlid = Field()
     url = Field()
-    response_url = Field()
-    status_code = Field()
+    responseUrl = Field()
+    statusCode = Field()
     success = Field()
     exception = Field()
     encoding = Field()
-    playground_id = Field()
+    playgroundId = Field()
     attrs = Field()
 
 
