@@ -160,10 +160,6 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
     async def _create_page(self, request: Request) -> Page:
         """Create a new page in a context, also creating a new context if necessary."""
-        logger.info(f"[{request.url}] Before acquire")
-        await self.context_semaphores['default'].acquire()
-        logger.info(f"[{request.url}] After acquire")
-
         context = self.contexts.get("default")
 
         page = await context.new_page()
@@ -210,54 +206,59 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         return deferred_from_coro(self._download_request(request, spider))
 
     async def _download_request(self, request: Request, spider: Spider) -> Response:
-        page = await self._create_page(request)
-
-        # attach event handlers
-        event_handlers = request.meta.get("playwright_page_event_handlers") or {}
-        for event, handler in event_handlers.items():
-            if callable(handler):
-                page.on(event, handler)
-            elif isinstance(handler, str):
-                try:
-                    page.on(event, getattr(spider, handler))
-                except AttributeError:
-                    logger.warning(
-                        f"Spider '{spider.name}' does not have a '{handler}' attribute,"
-                        f" ignoring handler for event '{event}'"
-                    )
-
-        await page.unroute("**")
-        await page.route(
-            "**",
-            self._make_request_handler(
-                method=request.method,
-                scrapy_headers=request.headers,
-                body=request.body,
-                encoding=getattr(request, "encoding", None),
-            ),
-        )
-
+        page = None
         try:
+            logger.info(f"[{request.url}] Before acquire")
+            await self.context_semaphores['default'].acquire()
+            logger.info(f"[{request.url}] After acquire")
+            page = await self._create_page(request)
+
+            # attach event handlers
+            event_handlers = request.meta.get("playwright_page_event_handlers") or {}
+            for event, handler in event_handlers.items():
+                if callable(handler):
+                    page.on(event, handler)
+                elif isinstance(handler, str):
+                    try:
+                        page.on(event, getattr(spider, handler))
+                    except AttributeError:
+                        logger.warning(
+                            f"Spider '{spider.name}' does not have a '{handler}' attribute,"
+                            f" ignoring handler for event '{event}'"
+                        )
+
+            await page.unroute("**")
+            await page.route(
+                "**",
+                self._make_request_handler(
+                    method=request.method,
+                    scrapy_headers=request.headers,
+                    body=request.body,
+                    encoding=getattr(request, "encoding", None),
+                ),
+            )
+
+            logger.info(f"[{request.url}] After route")
             result = await self._download_request_with_page(request, page)
-        except Exception:
-            if not page.is_closed():
-                await page.close()
-                self.stats.inc_value("playwright/page_count/closed")
-                self.context_semaphores['default'].release()
-            raise
+        except:
+            logger.exception(f"[{request.url}] Error while downloading request")
         else:
+            logger.info(f"[{request.url}] Return result")
+            return result
+        finally:
             await page.close()
             self.stats.inc_value("playwright/page_count/closed")
             self.context_semaphores['default'].release()
-            logger.info(f"[{request.url}] Return result")
-            return result
+
 
     async def _download_request_with_page(self, request: Request, page: Page) -> Response:
         start_time = time()
         response = await page.goto(request.url)
 
+        logger.info(f"[{request.url}] After goto")
         await self._apply_page_methods(page, request)
 
+        logger.info(f"[{request.url}] After apply page methods")
         body_str = await page.content()
         request.meta["download_latency"] = time() - start_time
 
